GridFixedHeightDelegate constructor
const
GridFixedHeightDelegate({})
Creates a delegate that makes grid layouts with a fixed number of tiles in the cross axis.
All of the arguments must not be null. The mainAxisSpacing and
crossAxisSpacing arguments must not be negative. The crossAxisCount
and childAspectRatio arguments must be greater than zero.
Implementation
const GridFixedHeightDelegate({
required this.crossAxisCount,
this.mainAxisSpacing = 0.0,
this.crossAxisSpacing = 0.0,
this.height = 56.0,
});